using System.Text;

namespace Generator_Class_BD.Clases.Transversales
{
    public static class UtilitariosTransversales
    {
        public static void EncabezadoMetodoGuardar(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo guardar " + vNombreEntidadL + "\n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"" + vNombreEntidadL + "\">Entidad a guardar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoGuardarLista(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo Guardar lista " + vNombreEntidadL + "\n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"lista" + vNombreEntidad + "\">Lista de entidades a guardar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoEditar(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo editar " + vNombreEntidadL + "\n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"" + vNombreEntidadL + "\">Entidad a editar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoConsultarLista(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo consultar lista " + vNombreEntidadL + "\n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoConsultarLlave(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo consultar por llave " + vNombreEntidadL + "\n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"" + vNombreEntidadL + "\">Entidad a consultar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoEliminar(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo eliminar " + vNombreEntidadL + "\n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"" + vNombreEntidadL + "\">Entidad a eliminar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoEditarPorQueryDal(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo editar " + vNombreEntidadL + " por query \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"filtro\">Filtro de las entidades </param>\n");
            cuerpo.Append("\t\t/// <param name=\"propiedades\">Propiedades a modificar</param>\n");
            cuerpo.Append("\t\t/// <param name=\"modificadores\">Nuevo valor de las propiedades a mofificar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoEditarPorQueryAsyncDal(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo editar " + vNombreEntidadL + " por query \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"filtro\">Filtro de las entidades </param>\n");
            cuerpo.Append("\t\t/// <param name=\"valor\">Entidad a mofificar</param>\n");
            cuerpo.Append("\t\t/// <param name=\"propiedades\">Propiedades a modificar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoConsultarListaPorFiltroDal(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo consultar lista " + vNombreEntidadL + " por filtro \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"" + vNombreEntidadL + "\">Entidad con los datos a filtrar</param>\n");
            cuerpo.Append("\t\t/// <param name=\"filtro\">Filtro de las entidades </param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoConsultarListaPorFiltroAsyncDal(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo consultar lista " + vNombreEntidadL + " por filtro \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"filtro\">Filtro de las entidades </param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoEditarPorFiltroDal(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo editar  " + vNombreEntidadL + " por filtro \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"" + vNombreEntidadL + "\">Entidad con los datos a editar</param>\n");
            cuerpo.Append("\t\t/// <param name=\"propiedades\">Propiedades a modificar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoEliminarListaPorFiltroDal(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo eliminar lista " + vNombreEntidadL + " por filtro \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"filtro\">Filtro de las entidades </param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoEliminarListaAsyncDal(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo eliminar lista " + vNombreEntidadL + " \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"lista\">Lista de entidad a eliminar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoEditarListaPorFiltroDal(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo editar " + vNombreEntidadL + " lista por filtro \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"lista\"> Lista con entidades a modificar</param>\n");
            cuerpo.Append("\t\t/// <param name=\"propiedades\">Propiedades a modificar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoEditarListaAsyncDal(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo editar " + vNombreEntidadL + " lista \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"lista\"> Lista con entidades a modificar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoEditarPorQueryBl(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo editar " + vNombreEntidadL + " por query \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"" + vNombreEntidadL + "\">Entidad a editar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoConsultarListaPorFiltroBl(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo consultar lista " + vNombreEntidadL + " por query \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"" + vNombreEntidadL + "\">Entidad a consultar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoEditarPorFiltroBl(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo editar " + vNombreEntidadL + " por filtro \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"" + vNombreEntidadL + "\">Entidad a editar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoEliminarListaPorFiltroBl(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo eliminar lista " + vNombreEntidadL + " por filtro \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"" + vNombreEntidadL + "\">Entidad a eliminar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoMetodoEditarListaPorFiltroBl(string vNombreEntidad, StringBuilder cuerpo, string vNombreEntidadL)
        {
            cuerpo.Append("\t\t/// <summary>\n");
            cuerpo.Append("\t\t/// Metodo editar lista " + vNombreEntidadL + " por filtro \n");
            cuerpo.Append("\t\t/// </summary>\n");
            cuerpo.Append("\t\t/// <param name=\"lista\">Entidad a editar</param>\n");
            cuerpo.Append("\t\t/// <returns>Respuesta tipo " + vNombreEntidad + " </returns>\n");
        }

        public static void EncabezadoDerechosAutor(string vNombreClase, StringBuilder cuerpo, string autor, string company)
        {
            cuerpo.Append("// ------------------------------------------------------------------------------------\n");
            cuerpo.Append("// <copyright file=\"" + vNombreClase + ".cs\"" + " company=\"" + company + "\">\n");
            cuerpo.Append("// Copyright (c) " + company + ". All rights reserved.\n");
            cuerpo.Append("// </copyright>\n");
            cuerpo.Append("// <author>" + autor + "</author>\n");
            cuerpo.Append("// ------------------------------------------------------------------------------------\n");
        }
    }
}